
#include <avr/pgmspace.h>      //save SRAM by putting strings in FLASH
#include <SoftwareSerial.h>
#include "shieldA_lib.h"
#include "MemoryFree.h"


//-----------------------------------------------------------------------------
// GLOBALS --------------------------------------------------------------------
//-----------------------------------------------------------------------------

unsigned long time;                //program run time

void debug2(String cmd, byte ret) {
  debug_print ( cmd,                    LEVEL_DEBUG, 1, 1 );
  debug_printP( PSTR(" ---> CMD RET --->: "), LEVEL_DEBUG, 1, 0 );
  debug_print ( String(ret),            LEVEL_DEBUG, 0, 1);
  util_printBuffer();
}


//-----------------------------------------------------------------------------
// SETUP ----------------------------------------------------------------------
//-----------------------------------------------------------------------------

void setup() {
  mySerial.begin(115200);
  mySerial.println("");

  glob_debug = 5;                  //Override global debug print level 

  cmd_setup();                     //set-up shield GPIO
  cmd_power();                     //power on
  cmd_connection();                //check cellular connection
}


//-----------------------------------------------------------------------------
// LOOP -----------------------------------------------------------------------
//-----------------------------------------------------------------------------

byte ret;

void loop() {
    
  //DEBUG LOOP STATEMENT
  debug_printP( PSTR("--- LOOP ---"),   LEVEL_DEBUG, 1, 1 );

  util_time();
  
  //DEBUG FREE MEMORY - (A VALUABLE RESOURCE!!!... which is why we're using PROGMEM)
  debug_printP( PSTR("FREE MEMORY()="), LEVEL_DEBUG, 1, 0 );
  debug_print( String(freeMemory()),    LEVEL_DEBUG, 0, 1 );
  
  //-----

  //BASIC AT COMMANDS
  //Nickname                       //at command     //Description

  util_time();
  debug_print( "ECHO",                  LEVEL_DEBUG, 1, 1 );
  ret = at_ate1();                 //at_echoOn      //Enable command echo
  debug2("ECHO", ret);
  util_clearBuffer();

  util_time();
  debug_print( "STATUS",                LEVEL_DEBUG, 1, 1 );
  ret = at_at();                   //at_status      //Quick status
  debug2("STATUS", ret);
  util_clearBuffer();
    
  util_time();
  debug_print( "REG",                   LEVEL_DEBUG, 1, 1 );
  ret = at_creg();                 //at_reg        #Network registration status
  debug2("REG", ret);
  util_clearBuffer();
    
  util_time();
  debug_print( "NETS",                  LEVEL_DEBUG, 1, 1 );
  ret = at_cops();                 //at_nets        //List available networks
  debug2("NETS", ret);
  util_clearBuffer();
    
  util_time();
  debug_print( "TECH",                  LEVEL_DEBUG, 1, 1 );
  ret = at_cnti();                 //at_tech        //Current tech
  debug2("TECH", ret);
  util_clearBuffer();
    
  util_time();
  debug_print( "SIG",                   LEVEL_DEBUG, 1, 1 );
  ret = at_csq();                  //at_sig         //Signal Quality
  debug2("SIG", ret);
  util_clearBuffer();


  delay(60000);
}

